#!/usr/bin/env node
const path = require("path");
const chalk = require("chalk");
const program = require("commander");
const packageJSON = require("./package.json");
const { copyFolderRecursiveSync } = require("./Utils");
const fs = require("fs");
const cliProgress = require("cli-progress");
const progressBar = new cliProgress.SingleBar({}, cliProgress.Presets.shades_classic);

program.version(packageJSON.version);

program
    .command("new")
    .arguments("<ProjectName>")
    .description("Its creates a new project.")
    .action(function(cmd, env) {
        cmdValue = cmd;
        envValue = env
    });

program.parse(process.argv);

//If commmand not found, then exit 1.
if (typeof cmdValue === "undefined") {
    console.error("no command given!");
    process.exit(1);
}

const projectName = cmdValue;
let source = null;
let target = null;

if (process.platform === "win32") {
    source = path.resolve(__dirname, "Base");
    target = process.cwd();
} else {
    source = `${__dirname}/Base`;
    target = process.env.PWD;
}

//Rename to projectName.
if (fs.existsSync(`${target}/${projectName}`)) {
    throw new Error(`Directory ${projectName} already exists.`);
}

console.log(chalk.green(`Creating ${projectName} project...`));
progressBar.start(200, 0);
copyFolderRecursiveSync(source, target, progressBar);

fs.renameSync(`${target}/Base`, `${target}/${projectName}`, (err) => {
    if (err) {
        progressBar.stop();
        throw err;
    }
});

progressBar.stop();
console.log(chalk.green(`Project ${projectName} created successfully.`));
